@@ -1,8 +1,5 @@
-from typing import Type
-
 import msgpack
 from django.utils.timezone import now
-from rest_framework.serializers import BaseSerializer
 
 from kitchenart.utils.broker import BasicPublisher, EventType
 
@@ -33,25 +30,16 @@ class LogPublisher(BasicPublisher):
                 event: EventType,
                 entity: str,
                 desc: str,
-                data_serializer: Type[BaseSerializer],
                 instance_old: any =None,
                 instance_new: any =None) -> None:
 
-        data_old = None
-        if instance_old:
-            data_old = data_serializer(instance_old, context=self.serializer_context()).data
-
-        data_new = None
-        if instance_new:
-            data_new = data_serializer(instance_new, context=self.serializer_context()).data
-
         body = self.construct_message(
             actor=actor,
             entity=entity,
             event=event,
             desc=desc,
-            data_old=data_old,
-            data_new=data_new
+            data_old=instance_old,
+            data_new=instance_new
         )
 
         routing_key = f'log.{entity}.{event.value}'
