@@ -6,7 +6,7 @@ from kitchenart.log.publisher import LogPublisher
 from kitchenart.utils.broker import EventType
 
 
-def publish_activity_log(sender, user, event, entity, serializer, instance_old, instance_new, **kwargs):
+def publish_activity_log(sender, user, event, entity, instance_old, instance_new, **kwargs):
     actor = f'{user.get_full_name()} <{user.email}>'
     description = None
     entity_name = entity.replace('_', ' ')
@@ -25,7 +25,6 @@ def publish_activity_log(sender, user, event, entity, serializer, instance_old,
             event=event,
             entity=entity,
             desc=description,
-            data_serializer=serializer,
             instance_old=instance_old,
             instance_new=instance_new
         )
